Instruments
===========

NIRSpec Dispersers
------------------

.. automodule:: unite.instruments.nirspec.disperser
   :members:
   :undoc-members:
   :show-inheritance:

NIRSpec Spectrum
----------------

.. automodule:: unite.instruments.nirspec.spectrum
   :members:
   :undoc-members:
   :show-inheritance:

SDSS Disperser
--------------

.. automodule:: unite.instruments.sdss.disperser
   :members:
   :undoc-members:
   :show-inheritance:

SDSS Spectrum
-------------

.. automodule:: unite.instruments.sdss.spectrum
   :members:
   :undoc-members:
   :show-inheritance:
